rai\_toolbox.perturbations.PerturbationModel
============================================

.. currentmodule:: rai_toolbox.perturbations

.. autoclass:: PerturbationModel

   
   .. automethod:: __init__
   .. automethod:: __call__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PerturbationModel.__init__
      ~PerturbationModel.__call__
   
   

   
   
   